@@ -2,11 +2,13 @@ from MyOverlay.funcs import myfunctions
 
 
 def InnitOverlay():
-    return myfunctions.StartOverlay()
+    screen = myfunctions.StartOverlay()
+    print(screen)
+    return screen
 
 
-def settext(text: str, PosX: int, PosY: int, font: str = 'Segoe UI Semibold', size: int = 30, opx: int = 2):
-    myfunctions.settext(text, PosX, PosY, font, size, opx)
+def settext(screen, text: str, PosX: int, PosY: int, font: str = 'Segoe UI Semibold', size: int = 30, opx: int = 2):
+    myfunctions.settext(screen, text, PosX, PosY, font, size, opx)
 
 
 def KillOverlay():
